%------------------------------------------------------------------%
% Projet Pinocchio -- main.ly                                      %
%                                                                  %
% (c) Classe de Valentin Villenave, 2009                           %
%                                                                  %
%------------------------------------------------------------------%

% Welcome to the Pinocchio project!
% Here are gathered several short piano pieces that were written by
% several students of mine in May-June 2009, after the story of
% Pinocchio, as written by Carlo Collodi in 1881-1882.

%% Illustrations by Enrico Mazzanti, courtesy of Wikimedia Commons.


\include "italiano.ly"
\version "2.13.0"

%% Common functions -----------------------------------------------%

%% tuplet shortcut (used everywhere).
t =
#(define-music-function (parser location music) (ly:music?)
#{ \times 2/3 $music #})

%% needed by pinoc_6.ly
k =
#(define-music-function (parser location music) (ly:music?)
#{ \repeat unfold 5 $music #})

%% needed by pinoc_5.ly
haut = { \change Staff = "haut" }
bas = { \change Staff = "bas" }

%% home-made accidental rules
#(define modern-accidentals-style
     `(Staff ,(make-accidental-rule 'same-octave 0)
             ,(make-accidental-rule 'any-octave 0)
             ,(make-accidental-rule 'same-octave 1)
                   ,neo-modern-accidental-rule))
#(define modern-cautionaries-style
     `(Staff ,(make-accidental-rule 'same-octave 1)
             ,(make-accidental-rule 'any-octave 1)))


%% Including the pieces -------------------------------------------%

\include "pinoc_1.ly"
\include "pinoc_2.ly"
\include "pinoc_3.ly"
\include "pinoc_4.ly"
\include "pinoc_5.ly"
\include "pinoc_6.ly"

%% Graphics and titling -------------------------------------------%


#(define-markup-command (vspace layout props amount) (number?)
  (let ((amount (* amount 3.0)))
    (if (> amount 0)
        (ly:make-stencil "" (cons -1 1) (cons 0 amount))
        (ly:make-stencil "" (cons -1 1) (cons amount amount)))))

MainTitre = \markup {
  \fill-line {
    \center-column {
      \vspace #5
      \bold \center-column {
        \fontsize #6 \with-color #(rgb-color 0.6 0.6 0.6) Les
        \fontsize #9 \with-color #(rgb-color 0.4 0.4 0.4) aventures
        \fontsize #8 \with-color #(rgb-color 0.2 0.2 0.2) de
        \fontsize #12 Pinocchio
      }
      \vspace #3
      \line{ \with-dimensions #'(0 . 10) #' (0 . 0) \draw-line #'(10 . 0) }
      \vspace #4
      \line {
        \hspace #5 \epsfile #X #40 #"pinoc.eps"
      }
    }
  }
}


Copyright = \markup {
  \vspace #25
  \fill-line {
   \override #'(box-padding . 1.0)
   \override #'(line-width . 100)
   \translate #'(-50 . 0)
  \rounded-box { 
    \left-column {
    \justify {
  Cette partition est le fruit du travail d'élèves de la classe de
  M. Villenave (http://valentin.villenave.net), et a été créée le 28 juin 2009
  à Saint-Maur des Fossés (Val de Marne).
    }
  \vspace #0.5
  \justify {La gravure est effectuée
    au moyen du logiciel libre GNU LilyPond (www.lilypond.org).}
    \vspace #0.5
    \justify {
  
  Le copyright pour chacune des pièces appartient à son auteur respectif ;
  ce recueil est publié sous licence \bold {Creative Commons} Paternité,
    Pas d'Utilisation Commerciale, Partage des Conditions Initiales à l'Identique.
  Voir http://creativecommons.org/licenses/by-nc-sa/ pour le texte complet de la licence.
 }
   
  \vspace #0.5
  \justify {
    Les illustrations de E. Mazzanti datent de l'édition originale des
    \italic {Aventures de Pinocchio,} et sont reproduites grâce au fonds
    WikiMedia Commons.
    }
    }
    }
  }
}

TagLine = \markup {
  \rounded-box \justify {
    Gravure réalisée au moyen du logiciel libre GNU LilyPond (www.lilypond.org).
  }
}

\layout {
  \context {
    \Score
    \override PaperColumn #'keep-inside-line = ##t
    \override NonMusicalPaperColumn #'keep-inside-line = ##t
    autoAccidentals = #modern-accidentals-style
    autoCautionaries = #modern-cautionaries-style
    extraNatural = ##f
  }
}
\paper {
  bottom-margin = #30
}

%% The actual score -----------------------------------------------%

\book {
  \header {
    title = \MainTitre
    tagline = ##f
    tagline = \TagLine
  }
  \pageBreak
  \markup \Copyright
  \pageBreak
  \score {
    \PinocUn
    \header {
      piece = \PinocUnTitre
    }
  }
  \markup \fill-line { \epsfile #Y #15 #"pantin.eps" }
  \pageBreak
  \score {
    \PinocDeux
    \header {
      piece = \PinocDeuxTitre
    }
  }
  \pageBreak
  \markup \fill-line {
    \center-column {
      \vspace #15 \epsfile #Y #50 #"grillon.eps"
    }
  }
  \pageBreak
  \score {
    \PinocTrois
    \header {
      piece = \PinocTroisTitre
    }
  }
  \pageBreak
  \score {
    \PinocQuatre
    \header {
      piece = \markup
        \fill-line {
          \center-column {
            \PinocQuatreTitre
            \epsfile #Y #40 #"chat.eps"
          }
        }
    }
  }
  \pageBreak
  \score {
    \PinocCinq
    \header {
      piece = \PinocCinqTitre
    }
  }

%% Commented out because the piece isn't finished.  
% \pageBreak
%  \score {
%    \PinocSix
%    \header {
%      piece = \PinocSixTitre
%    }
%  }
}
